@@ -7,14 +7,15 @@ from django_utils.filters import OnTheFlyOrderingFilter, OnTheFlySearchFilter, W
     WithCreatedOrderingFilter
 from django_utils.permissions import CustomObjectPermissions
 from guardian_queryset.filters import GuardianViewPermissionsFilter
+from rest_framework import mixins, generics
 from rest_framework import status
-from rest_framework import viewsets, mixins, generics
+from rest_framework import viewsets, filters
 from rest_framework.response import Response
 from rest_framework.viewsets import GenericViewSet
 
 
 class DefaultPrivateApiViewMixin(generics.GenericAPIView):
-    filter_backends = [WithCreatedOrderingFilter,WithCreatedSearchFilter,GuardianViewPermissionsFilter]
+    filter_backends = [WithCreatedOrderingFilter,WithCreatedSearchFilter,GuardianViewPermissionsFilter, filters.OrderingFilter]
     permission_classes = [CustomObjectPermissions]
     ordering = ['-id']
 
@@ -23,7 +24,7 @@ class DefaultPrivateViewSetMixin(DefaultPrivateApiViewMixin):
 
 
     def get_defaults(self):
-        return {}
+        return {'user': self.request.user}
 
     def get_queryset(self):
         return self.queryset.filter(**self.get_defaults())
